(function ($, Drupal, once) {
  Drupal.behaviors.sortParagraphsAlpha = {
    attach(context) {
      once('sort-paragraphs', '.paragraphs-sort-alpha', context).forEach(
        (button) => {
          button.addEventListener('click', (e) => {
            e.preventDefault();

            const sortField = button.getAttribute('data-sort-field');
            if (!sortField) {
              console.warn('Missing data-sort-field attribute.');
              return;
            }

            const fieldClass = `field--name-${sortField.replace(/_/g, '-')}`;
            const wrapper = button.closest(`.${fieldClass}`);
            const table = wrapper ? wrapper.querySelector('table') : null;
            if (!table) {
              console.warn(`Could not find table for sort field: ${sortField}`);
              return;
            }

            const tbody = table.querySelector('tbody');
            if (!tbody) {
              console.warn('No tbody found in table.');
              return;
            }

            const rows = Array.from(tbody.querySelectorAll('tr'));

            // Sort rows alphabetically by the specified field's input value.
            rows.sort((a, b) => {
              const inputA = a.querySelector(
                `.paragraphs-subform input[name^="${sortField}"]`,
              );
              const inputB = b.querySelector(
                `.paragraphs-subform input[name^="${sortField}"]`,
              );

              // Try to get value from input, otherwise fallback to summary.
              const valA =
                inputA?.value?.trim().toUpperCase() ||
                a
                  .querySelector('.paragraph-summary .summary-content')
                  ?.textContent?.trim()
                  .toUpperCase() ||
                a
                  .querySelector('.paragraphs-description .summary-content')
                  ?.textContent?.trim()
                  .toUpperCase() ||
                '';
              const valB =
                inputB?.value?.trim().toUpperCase() ||
                b
                  .querySelector('.paragraph-summary .summary-content')
                  ?.textContent?.trim()
                  .toUpperCase() ||
                b
                  .querySelector('.paragraphs-description .summary-content')
                  ?.textContent?.trim()
                  .toUpperCase() ||
                '';

              return valA.localeCompare(valB);
            });

            // Re-append sorted rows to tbody.
            rows.forEach((row, index) => {
              tbody.appendChild(row);
              // Update weight input if present
              const weightSelect = row.querySelector(
                'select[name$="[_weight]"]',
              );
              if (weightSelect) {
                weightSelect.value = index;
              }
            });
          });
        },
      );
    },
  };
})(jQuery, Drupal, once);
