<?php

namespace Drupal\paragraphs_sort_alphabetically_widget\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;

/**
 * Provides helper functions for Paragraphs Sort Widget.
 */
trait ParagraphsAlphaSortHelperTrait {

  /**
   * Add the sort button to the render.
   *
   * @param array $element
   *   Form element.
   * @param \Drupal\Core\Field\FieldItemListInterface $items
   *   Fields list.
   */
  public function addSortButton(array $element, FieldItemListInterface $items): array {

    // Ensure Paragraphs styling/behavior applies.
    $element['#attributes']['class'][] = 'field--widget-paragraphs';

    // Add our own class for targeting.
    $element['#attributes']['class'][] = 'field--widget-paragraphs-alpha-sort';

    if (isset($element['add_more'])) {
      $element['add_more']['sort_alpha'] = [
        '#type' => 'button',
        '#value' => $this->t('Sort Alphabetically'),
        '#attributes' => [
          'class' => ['button--small button', 'paragraphs-sort-alpha'],
          'data-sort-field' => $items->getName(),
        ],
        '#weight' => 100,
      ];

      $element['#attached']['library'][] = 'paragraphs_sort_alphabetically_widget/sort_paragraphs';
    }

    return $element;
  }

}
