<?php

namespace Drupal\Tests\paragraphs_sort_alphabetically_widget\FunctionalJavascript;

use Drupal\Core\Entity\Entity\EntityFormDisplay;
use Drupal\FunctionalJavascriptTests\WebDriverTestBase;
use Drupal\Tests\paragraphs\FunctionalJavascript\ParagraphsTestBaseTrait;

/**
 * Test paragraphs_sort_alphabetically_widget widget.
 *
 * @group paragraphs_sort_alphabetically_widget
 */
class ParagraphsSortWidgetTest extends WebDriverTestBase {

  use ParagraphsTestBaseTrait;

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = [
    'node',
    'paragraphs_sort_alphabetically_widget',
    'field',
    'field_ui',
    'text',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Test the widget functionality.
   *
   * @throws \Behat\Mink\Exception\ElementNotFoundException
   * @throws \Behat\Mink\Exception\ResponseTextException
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function testParagraphAlphaSortWidget(): void {
    $this->addParagraphedContentType('paragraphed_content_demo', 'field_paragraphs_demo');
    $this->addParagraphsType('text');
    $this->addFieldtoParagraphType('text', 'field_text_demo', 'text');

    // Set the custom widget.
    $entity_form_display = EntityFormDisplay::load('node.paragraphed_content_demo.default');
    $entity_form_display->setComponent('field_paragraphs_demo', [
      'type' => 'paragraphs_alpha_sort',
    ]);
    $entity_form_display->save();

    $this->drupalLogin($this->drupalCreateUser([
      'administer site configuration',
      'create paragraphed_content_demo content',
      'edit any paragraphed_content_demo content',
      'delete any paragraphed_content_demo content',
    ]));

    // Create a node and add a paragraph.
    $page = $this->getSession()->getPage();
    $this->drupalGet('node/add/paragraphed_content_demo');

    // Add Paragraph 1: A test.
    $page->fillField('field_paragraphs_demo[0][subform][field_text_demo][0][value]', 'A test');

    // Add Paragraph 2: C test.
    $page->pressButton('Add text');
    $this->assertSession()->assertWaitOnAjaxRequest();
    $page->fillField('field_paragraphs_demo[1][subform][field_text_demo][0][value]', 'C test');

    // Add Paragraph 3: B test.
    $page->pressButton('Add text');
    $this->assertSession()->assertWaitOnAjaxRequest();
    $page->fillField('field_paragraphs_demo[2][subform][field_text_demo][0][value]', 'B test');

    // Click "Sort Alphabetically" button.
    $sort_button = $page->find('css', '.paragraphs-sort-alpha');
    $this->assertNotNull($sort_button, 'Sort button is present.');
    $sort_button->press();

    // Save the node.
    $page->fillField('title[0][value]', 'Test widget');
    $page->pressButton('Save');
    $this->assertSession()->pageTextContains('paragraphed_content_demo Test widget has been created');

    $page = $this->getSession()->getPage();
    $paragraphs = $page->findAll('css', '.paragraph--type--text');

    $values = [];
    foreach ($paragraphs as $paragraph) {
      $values[] = trim($paragraph->find('css', 'div > div:nth-child(2)')->getText());
    }

    // Now assert order.
    $this->assertEquals(['A test', 'B test', 'C test'], $values);
  }

}
